@@ -31,7 +31,7 @@ def fis_dark_theme():
     rcParams['ytick.color'] = light_white
     rcParams['axes.grid'] = True
     rcParams['grid.color'] = light_white
-    rcParams['grid.alpha'] = .1
+    rcParams['grid.alpha'] = .3
     rcParams['axes.prop_cycle'] = cycler(color=dark_theme_colors)
     rcParams['image.cmap'] = 'inferno'
 
@@ -43,8 +43,9 @@ def fis_light_theme():
     dark_theme_colors + ["#ea5545", "#f46a9b", "#ef9b20", "#edbf33", "#ede15b", "#bdcf32", "#87bc45", "#27aeef", "#b33dc6"]
     dark_theme_colors + ["#e60049", "#0bb4ff", "#50e991", "#e6d800", "#9b19f5", "#ffa300", "#dc0ab4", "#b3d4ff", "#00bfa0"]
     rcParams['figure.figsize'] = 10,8
+    rcParams['axes.edgecolor'] = "#545aa7"
     rcParams['axes.grid'] = True
     rcParams['grid.alpha'] = .3
     rcParams['axes.prop_cycle'] = cycler(color=dark_theme_colors)
     rcParams['grid.color'] = light_white
-    rcParams['image.cmap'] = 'inferno'
\ No newline at end of file
+    rcParams['image.cmap'] = 'inferno'
